/******************************************************************
*****************  				KENYA 			  *****************
*****************  		Decision making paper	  *****************

*** PURPOSE: This do-file replicates all tables and figures of the decision making paper 
			  
Date: December, 2024
Stata version: 18
******************************************************************/		
/*			   
clear all
set more off
set dp period
set seed 1001

*** Work directory
   if "`c(username)'"=="marti" {
		global main   = "C:\Users\marti\Dropbox\Trabajos-Concursos-etc\Oxford-WEAI\Kenya Water Survey round 2\Data and dofiles\Replication package"
	}
else if "`c(username)'"=="mquerejeta" {
		global main   = "C:\Users\mquerejeta\Dropbox\Trabajos-Concursos-etc\Oxford-WEAI\Kenya Water Survey round 2\Data and dofiles\Replication package"
	}
else if "`c(username)'"=="hille" {
		global main   = "C:\Users\hille\Dropbox\Oxford-WEAI\Kenya Water Survey round 2\Data and dofiles\Replication package"
	}
	*/
global result="$main"

grstyle init
grstyle set plain, horizontal compact // Fondo blanco
grstyle color xyline gs10 // added line color
grstyle set legend 6, nobox
grstyle set color hue, n(4) // ggplot2

*******************************************************************
* Table 1. Descriptive Statistics
*******************************************************************
use "$main\Data_exploring_DM.dta", clear
global individual="y_age categ_hh_1-categ_hh_5 wi_div_sep educ_attending educ_illiterate educ_primary educ_sec_tert "
keep b01 y_id sampling female $individual
duplicates drop
format $individual %4.2f
qui: balancetable (mean if female==1) (mean if female==0) $individual [aw=sampling] ///
	using "$main\FINAL_Tables.xls", modify sheet(Table1) cell(A2) leftctitle(none) displayformat format(2) /// 
	 varlabels ctitles("Women" "Men" "Diff")

use "$main\Data_exploring_DM.dta", clear
keep b01 y_id sampling female dm1-dm7 all none
drop *_
duplicates drop
ta fem
format dm1-dm7 all none %4.2f
qui: balancetable (mean if female==1) (mean if female==0) dm1-dm7 all none [aw=sampling] ///
	using "$result\FINAL_Tables.xls", modify sheet(Table1) cell(A27) leftctitle(none) displayformat format(2) /// 
	 varlabels ctitles("Women" "Men" "Diff")

*******************************************************************
* Data in the main text
*******************************************************************
*The quantitative data confirms that while women are more likely than men to make the decisions about the water source for drinking, the decisions are often made jointly. 
use "$main\Data_exploring_DM.dta", clear
ta dm_categ female [aw=sampling] if water==1, col nof

*But it varies by household structure. When the husband has more than one wife, he may not be in the home often. As such, a wife is delegated more of the decision-making responsibility. 
use "$main\Data_exploring_DM.dta", clear
drop perc_authority
keep if dm_categ==3 // Only non-DM
merge 1:1 b01 y_id activity_id using "$main\DM_who_max_authority.dta"
keep if _m==3 // missing 104 ind-act observations with no info in relation
drop _m
global hhrel="wife_cowife wife cowife husband dau son dauinlaw soninlaw dau_dauinlaw son_soninlaw granddau grandson mother_stepm father_stepf mother_inlaw father_inlaw sis bro sisinlaw broinlaw sis_sisinlaw bro_broinlaw niece nephew aunt uncle grandmother grandfather"
sum $hhrel [aw=sampling] if water==1 & female==0 & categ_hh==4

*  In extended family households... The mother-in-law does not fetch the water typically but may have other chores and she may participate in decisions on water expenditures.
sum $hhrel [aw=sampling] if expenditure==1 & female==0 & categ_hh==2

* Compared to men, women are less likely to be directly involved in individual-level (or personal) decisions such as health care for self, visiting family, and the use of own income.  Even so, there is significant number of men (31 percent of men) who also do not directly participate in at least one individual-level decision. There are 11 percent of men who do not directly participate in two or more individual-level decisions. These are primarily young men who have not yet started their own household.
use "$main\Data_exploring_DM.dta", clear
keep if activity_id==5|activity_id==6|activity_id==7
g nondm_ind_=(dm_categ==3)
egen nondm_ind=sum(nondm_ind_), by(b01 y_id)
keep b01 y_id female nondm_ind sampling y_age hh_parents
duplicates drop
ta nondm_ind if female==0 [aw=sampling]
mean y_age hh_parents if female==0 & (nondm_ind==2|nondm_ind==3) [aw=sampling]
mean y_age hh_parents if female==0  [aw=sampling]

*******************************************************************
* Figure 1. 
*******************************************************************
use "$main\Data_exploring_DM.dta", clear
keep if dm_categ==3
g act=1
keep b01 y_id female act cant_nondm activity_id sampling
reshape wide act, i(b01 y_id female cant_nondm sampling) j(activity_id)
recode act* (.=0)

g dist=.
forval j = 1/7 { 
    egen disp`j' = mean(cant_nondm== `j'), by(female) 
	replace dist=disp`j' if cant_nondm== `j'
	drop disp`j'
} 
collapse (mean) act* dist [aw=sampling], by(female cant_nondm)
forval j = 1/7 { 
	g act`j'_r=(act`j'*dist)*100/cant_nondm
}
local title0="Men"
local title1="Women"
local name0="men"
local name1="fem"
forvalues if =0/1 {
colorpalette hue, select(1 5 9) nograph
graph bar act1_r act3_r act2_r act4_r-act7_r if female==`if', stack over(cant_nondm) ///
bar(1, bcolor("`r(p3)'")) /// 
bar(2, bcolor("`r(p3)'*0.5")) /// 
bar(3, bcolor("`r(p2)'")) /// 
bar(4, bcolor("`r(p2)'*0.5")) /// 
bar(5, bcolor("`r(p1)'")) /// 
bar(6, bcolor("`r(p1)'*0.7")) /// 
bar(7, bcolor("`r(p1)'*0.2")) /// 
		ytitle("", size(small))  ///
		legend(label(1 "Water source for drinking") label(2 "Water allocation and use") label(3 "Regular water expenditure") label(4 "Large household purchases") label(5 "Health care for yourself") label(6 "Visit family or relatives") label(7 "Use the money you earn")) legend(rows(2) size(small)) ///
	    title("`title`if'''s responses", size(medsmall)) name(`title`if'', replace)
*graph export "$result\N_nonDM_`name`if''.png", as(png) replace 
}
grc1leg2 Men Women, legendfrom(Men) lrows(2) labsize(small) b2title("Number of decisions not directly involved", size(medsmall)) l1title("Percentage", size(medsmall)) ring(2)
graph export "$main\N_nonDM.png", as(png) replace 
graph close

*******************************************************************
* Data in main text. 
*******************************************************************
*For those with effective power by proxy, 82 percent of preferences for first choice aligned with the household's actual choice of drinking water.
use "$main\Data_exploring_DM.dta", clear
ta best1_used proxy_p [aw=sampling] if activity_id==1, col nof

* preferences are more likely to align with the outcome for men with effective power by proxy than for women (86 percent compared to 63 percent)
ta best1_used proxy_p [aw=sampling] if activity_id==1 & female==0, col nof 
ta best1_used proxy_p [aw=sampling] if activity_id==1 & female==1, col nof

*******************************************************************
* Table 2. 
*******************************************************************
use "$main\Data_exploring_DM.dta", clear
g dm_categ1=(dm_categ==1)
g dm_categ2=(dm_categ==2)
egen total_categ3=sum(dm_categ3), by(female activity_id)
replace proxy_power=. if dm_categ!=3 
replace persuasion_power=. if dm_categ!=3 
replace effective_power=. if dm_categ!=3 
g NO_effective_power=(effective_power==0) if effective_power!=.
lab var dm_categ3 "Share who are not a decision maker"
lab var proxy_power "(1) Effective power by proxy"
lab var persuasion_power "(2) Effective power by persuasion"
lab var effective_power "Effective power"
lab var NO_effective_power "No effective power"
lab var total_categ3 "Obs. Of those who do not make the decision"
local A=2
forvalues if =1/7 {
format dm_categ3 proxy_power persuasion_power effective_power NO_effective_power %4.2f
qui: balancetable female dm_categ3 proxy_power persuasion_power effective_power NO_effective_power total_categ3 [aw=sampling] if activity_id==`if' using "$main\FINAL_Tables.xls", modify sheet(Table2) cell(A`A') leftctitle(none) displayformat format(2) varlabels ctitles("Men" "Women" "Diff") 
local A=`A'+17
}	

*******************************************************************
* Table 3. 
*******************************************************************
use "$main\Data_exploring_DM.dta", clear
keep b01 y_id female sampling categ_hh share_effective_power* share_dm* nondm 
duplicates drop 
duplicates report  b01 y_id
ta female nondm // Individual level - 1,059 women & 808 men
g men=(female==0) 
lab var share_effective_power "Share of all decisions not directly involved but have effective power"

format share_dm share_dm_water share_dm_exp share_dm_ind share_effective_power share_effective_power_water share_effective_power_exp share_effective_power_ind %4.2f

qui: balancetable men share_effective_power if nondm==1 [aw=sampling] using "$main\FINAL_Tables.xls", modify sheet(Table3) cell(A2) leftctitle(none) displayformat format(2) varlabels ctitles("Women" "Men" "Diff")

*******************************************************************
* Table 4. 
*******************************************************************
lab var share_effective_power "All decisions"
*** Married in couple households (69 men and 77 women)
* Average share of decision-making activities in which wives and husband participate in the decision
qui: balancetable men share_dm share_dm_water share_dm_exp share_dm_ind if categ_hh==1 [aw=sampling] using "$main\FINAL_Tables.xls", modify sheet(Table4) cell(A2) leftctitle(none) displayformat format(2) varlabels ctitles("Women" "Men" "Diff")
*  Average share of decision-making activities in which wives and husbands do not participate directly in the decision but have effective power
qui: balancetable men share_effective_power share_effective_power_water share_effective_power_exp share_effective_power_ind if nondm==1 & categ_hh==1 [aw=sampling] using "$main\FINAL_Tables.xls", modify sheet(Table4) cell(E2) leftctitle(none) displayformat format(2) varlabels ctitles("Women" "Men" "Diff")

*** Married in extended households who live with wives' in-laws (195 men and 220 women)
* Average share of decision-making activities in which wives and husband participate in the decision
qui: balancetable men share_dm share_dm_water share_dm_exp share_dm_ind if categ_hh==2 [aw=sampling] using "$main\FINAL_Tables.xls", modify sheet(Table4) cell(A13) leftctitle(none) displayformat format(2) varlabels ctitles("Women" "Men" "Diff")
*  Average share of decision-making activities in which wives and husbands do not participate directly in the decision but have effective power
qui: balancetable men share_effective_power share_effective_power_water share_effective_power_exp share_effective_power_ind if nondm==1 & categ_hh==2 [aw=sampling] using "$main\FINAL_Tables.xls", modify sheet(Table4) cell(E13) leftctitle(none) displayformat format(2) varlabels ctitles("Women" "Men" "Diff")

*** Married in households with cowives (not very many of these)
* Average share of decision-making activities in which wives and husband participate in the decision
qui: balancetable men share_dm share_dm_water share_dm_exp share_dm_ind if categ_hh==4 [aw=sampling] using "$main\FINAL_Tables.xls", modify sheet(Table4) cell(A24) leftctitle(none) displayformat format(2) varlabels ctitles("Women" "Men" "Diff")
*  Average share of decision-making activities in which wives and husbands do not participate directly in the decision but have effective power
qui: balancetable men share_effective_power share_effective_power_water share_effective_power_exp share_effective_power_ind if nondm==1 & categ_hh==4 [aw=sampling] using "$main\FINAL_Tables.xls", modify sheet(Table4) cell(E24) leftctitle(none) displayformat format(2) varlabels ctitles("Women" "Men" "Diff")

*******************************************************************
* Table 5. 
*******************************************************************
* Average share of decision-making activities in which wives and husband participate in the decision
qui: balancetable men share_dm share_dm_water share_dm_exp share_dm_ind if categ_hh==5 [aw=sampling] using "$main\FINAL_Tables.xls", modify sheet(Table5) cell(A2) leftctitle(none) displayformat format(2) varlabels ctitles("Women" "Men" "Diff")
*  Average share of decision-making activities in which wives and husbands do not participate directly in the decision but have effective power
qui: balancetable men share_effective_power share_effective_power_water share_effective_power_exp share_effective_power_ind if nondm==1 & categ_hh==5 [aw=sampling] using "$main\FINAL_Tables.xls", modify sheet(Table5) cell(E2) leftctitle(none) displayformat format(2) varlabels ctitles("Women" "Men" "Diff")

*******************************************************************
* Table A.1. 
*******************************************************************
use "$main\Full_sample.dta", clear
g full=1
append using "$main\Data_exploring_DM.dta"
replace full=0 if full==.
g sample=(full==0)
global individual="y_age never_married mono_married pol_married wi_div_sep educ_attending educ_illiterate educ_primary educ_sec_tert"
global household="hh_parents hh_inlaws ht_single ht_couple ht_extended ht_cowives Ganze Kaloleni Magarini"
keep b01 y_id sampling female sample $individual $household
duplicates drop
format  $individual $household %4.2f
qui: balancetable sample $individual $household [aw=sampling] if female==1 using "$main\FINAL_Tables.xls", modify sheet(TableA1) cell(A2) leftctitle(none) displayformat format(2) varlabels ctitles("Women in the household roster" "Women Sample" "Diff")
qui: balancetable sample $individual $household [aw=sampling] if female==0 using "$main\FINAL_Tables.xls", modify sheet(TableA1) cell(F2) leftctitle(none) displayformat format(2) varlabels ctitles("Men in the household roster" "Men Sample" "Diff")	 

*******************************************************************
*** 	THE END
*******************************************************************